# dojah-python-sdk
Use Dojah to verify, onboard and manage user identity across Africa!

This Python package is automatically generated by the [Konfig](https://konfigthis.com):

- API version: 1.0.0
- Package version: 1.0.0

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install dojah-python-sdk==1.0.0
```
(you may need to run `pip` with root permission: `sudo pip install dojah-python-sdk==1.0.0`)

Then import the package:
```python
import dojah_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import dojah_client
from pprint import pprint
from dojah_client.api import aml_api
from dojah_client.model.get_screening_info_response import GetScreeningInfoResponse
from dojah_client.model.screen_aml_response import ScreenAmlResponse

# Configure base path by assigning "server_index"
# configuration.server_index = 0 # https://api.dojah.io
# configuration.server_index = 1 # https://sandbox.dojah.io

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: apikeyAuth
configuration = dojah_client.Configuration(api_key={'apikeyAuth': 'YOUR_API_KEY'})

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['apikeyAuth'] = 'Bearer'

# Configure API key authorization: appIdAuth
configuration.api_key['appIdAuth'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['appIdAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with dojah_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = aml_api.AMLApi(api_client)
    reference_id = "c574a3c8-dc27-4013-8bbc-462e7ed87d55" # str |  (optional)

    try:
        # Get AML Info
        api_response = api_instance.get_screening_info(reference_id=reference_id)
        pprint(api_response)
    except dojah_client.ApiException as e:
        print("Exception when calling AMLApi->get_screening_info: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.dojah.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AMLApi* | [**get_screening_info**](docs/AMLApi.md#get_screening_info) | **GET** /v1/aml/screening/info | Get AML Info
*AMLApi* | [**screen_aml**](docs/AMLApi.md#screen_aml) | **POST** /api/v1/aml/screening | AML Screening
*AuthenticationApi* | [**get_sender_id**](docs/AuthenticationApi.md#get_sender_id) | **GET** /api/v1/messaging/sender_ids | Messaging - Get Sender IDs
*AuthenticationApi* | [**get_sms_status**](docs/AuthenticationApi.md#get_sms_status) | **GET** /v1/messaging/sms/get_status | Messaging - Get SMS Status
*AuthenticationApi* | [**request_sender_id**](docs/AuthenticationApi.md#request_sender_id) | **POST** /api/v1/messaging/sender_id | Messaging - Request Sender ID
*AuthenticationApi* | [**send_otp**](docs/AuthenticationApi.md#send_otp) | **POST** /v1/messaging/otp | Messaging - Send OTP
*AuthenticationApi* | [**send_sms**](docs/AuthenticationApi.md#send_sms) | **POST** /api/v1/messaging/sms | Messaging - Send SMS
*AuthenticationApi* | [**validate_otp**](docs/AuthenticationApi.md#validate_otp) | **GET** /v1/messaging/otp/validate | Messaging - Validate OTP
*FinancialApi* | [**collect_status_from_pdf**](docs/FinancialApi.md#collect_status_from_pdf) | **POST** /api/v1/financial/transactions/pdf | Collect Status via PDF Statement
*FinancialApi* | [**collect_transactions**](docs/FinancialApi.md#collect_transactions) | **POST** /v1/financial/transactions | Collect Transactions
*FinancialApi* | [**get_account**](docs/FinancialApi.md#get_account) | **GET** /api/v1/financial/account_information | Get Account Information
*FinancialApi* | [**get_account_analysis**](docs/FinancialApi.md#get_account_analysis) | **GET** /api/v1/financial/analysis | Get Account Analysis
*FinancialApi* | [**get_account_subscriptions**](docs/FinancialApi.md#get_account_subscriptions) | **GET** /v1/financial/account_subscription | Get Account Subscriptions
*FinancialApi* | [**get_account_transactions**](docs/FinancialApi.md#get_account_transactions) | **GET** /api/v1/financial/account_transactions | Get Account Transactions
*FinancialApi* | [**get_basic_bvn**](docs/FinancialApi.md#get_basic_bvn) | **GET** /v1/financial/bvn_information/basic | Get BVN Information Basic
*FinancialApi* | [**get_earning_structure**](docs/FinancialApi.md#get_earning_structure) | **GET** /v1/financial/earning_structure | Get Earning Structure
*FinancialApi* | [**get_full_bvn**](docs/FinancialApi.md#get_full_bvn) | **GET** /v1/financial/bvn_information/full | Get BVN Information Full
*FinancialApi* | [**get_spending_pattern**](docs/FinancialApi.md#get_spending_pattern) | **GET** /v1/financial/spending_pattern | Get Spending Pattern
*GHKYCApi* | [**get_drivers_license**](docs/GHKYCApi.md#get_drivers_license) | **GET** /api/v1/gh/kyc/dl | Driver&#39;s License
*GHKYCApi* | [**get_passport**](docs/GHKYCApi.md#get_passport) | **GET** /api/v1/gh/kyc/passport | Passport
*GHKYCApi* | [**get_ssnit**](docs/GHKYCApi.md#get_ssnit) | **GET** /api/v1/gh/kyc/ssnit | SSNIT
*GeneralApi* | [**get_banks**](docs/GeneralApi.md#get_banks) | **GET** /v1/general/banks | General - Get Banks
*GeneralApi* | [**get_bin**](docs/GeneralApi.md#get_bin) | **GET** /v1/general/bin | General Resolve BIN
*GeneralApi* | [**get_data_plans**](docs/GeneralApi.md#get_data_plans) | **GET** /v1/purchase/data/plans | Purchase - Get Data Plans
*GeneralApi* | [**get_nuban**](docs/GeneralApi.md#get_nuban) | **GET** /v1/general/account | General Resolve NUBAN
*GeneralApi* | [**get_wallet_balance**](docs/GeneralApi.md#get_wallet_balance) | **GET** /api/v1/balance | Get Dojah Wallet Balance
*GeneralApi* | [**purchase_airtime**](docs/GeneralApi.md#purchase_airtime) | **POST** /v1/purchase/airtime | Purchase - Send Airtime
*GeneralApi* | [**purchase_data**](docs/GeneralApi.md#purchase_data) | **POST** /v1/purchase/data | Purchase - Buy Data
*KEKYCApi* | [**get_national_id**](docs/KEKYCApi.md#get_national_id) | **GET** /api/v1/ke/kyc/id | KYC - National ID
*KYBApi* | [**get_advanced_cac**](docs/KYBApi.md#get_advanced_cac) | **GET** /v1/kyc/cac/advance | KYC - Get CAC Advanced
*KYBApi* | [**get_basic_cac**](docs/KYBApi.md#get_basic_cac) | **GET** /v1/kyc/cac/basic | KYB - Get CAC 2
*KYBApi* | [**get_cac**](docs/KYBApi.md#get_cac) | **GET** /v1/kyc/cac | KYC - Get CAC 
*KYBApi* | [**get_tin**](docs/KYBApi.md#get_tin) | **GET** /v1/kyc/tin | KYC - Fetch Tin
*KYCApi* | [**analyze_document**](docs/KYCApi.md#analyze_document) | **POST** /api/v1/document/analysis | KYC - Document Analysis
*KYCApi* | [**get_basic_bvn**](docs/KYCApi.md#get_basic_bvn) | **GET** /api/v1/kyc/bvn/basic | KYC - Get Basic BVN Info
*KYCApi* | [**get_basic_phone_number**](docs/KYCApi.md#get_basic_phone_number) | **GET** /v1/kyc/phone_number/basic | KYC Lookup Phone Number Basic
*KYCApi* | [**get_drivers_license**](docs/KYCApi.md#get_drivers_license) | **GET** /api/v1/kyc/dl | KYC - Get Drivers License Info
*KYCApi* | [**get_email_reputation**](docs/KYCApi.md#get_email_reputation) | **GET** /v1/kyc/email | KYC - Get Email Reputation
*KYCApi* | [**get_full_bvn**](docs/KYCApi.md#get_full_bvn) | **GET** /api/v1/kyc/bvn/full | KYC - Lookup BVN Basic
*KYCApi* | [**get_nuban**](docs/KYCApi.md#get_nuban) | **GET** /api/v1/kyc/nuban | KYC - Get NUBAN Information
*KYCApi* | [**get_passport**](docs/KYCApi.md#get_passport) | **GET** /api/v1/kyc/passport | KYC - Passport
*KYCApi* | [**get_phone_number**](docs/KYCApi.md#get_phone_number) | **GET** /api/v1/kyc/phone_number | KYC - Lookup Phone Number
*KYCApi* | [**get_premium_bvn**](docs/KYCApi.md#get_premium_bvn) | **GET** /api/v1/kyc/bvn/advance | KYC - Lookup BVN Premium
*KYCApi* | [**get_vin**](docs/KYCApi.md#get_vin) | **GET** /api/v1/kyc/vin | KYC - Get VIN
*KYCApi* | [**get_vnin**](docs/KYCApi.md#get_vnin) | **GET** /api/v1/kyc/vnin | Lookup VNIN
*KYCApi* | [**validate_bvn**](docs/KYCApi.md#validate_bvn) | **GET** /api/v1/kyc/bvn | KYC - Validate BVN
*KYCApi* | [**verify_age**](docs/KYCApi.md#verify_age) | **GET** /v1/kyc/age_verification | KYC - Age Verification
*KYCApi* | [**verify_selfie_bvn**](docs/KYCApi.md#verify_selfie_bvn) | **POST** /v1/kyc/bvn/verify | KYC - Selfie BVN Verificatoin
*KYCApi* | [**verify_selfie_nin**](docs/KYCApi.md#verify_selfie_nin) | **POST** /v1/kyc/nin/verify | KYC - Selfie NIN Verification
*MLApi* | [**get_document_analysis**](docs/MLApi.md#get_document_analysis) | **POST** /v1/document/analysis/dl | Document Analysis Drivers License
*MLApi* | [**get_generic_ocr_text**](docs/MLApi.md#get_generic_ocr_text) | **POST** /v1/ml/ocr/generic | Generic OCR Service
*MLApi* | [**get_ocr_text**](docs/MLApi.md#get_ocr_text) | **POST** /v1/ml/ocr | BVN Ocr
*MLApi* | [**verify_photo_id_with_selfie**](docs/MLApi.md#verify_photo_id_with_selfie) | **POST** /v1/kyc/photoid/verify | KYC - Selfie Photo ID Verification
*ServicesApi* | [**categorize_transactions**](docs/ServicesApi.md#categorize_transactions) | **POST** /v1/ml/categorize_transaction | Categorize Transactions
*UGKYCApi* | [**get_voter**](docs/UGKYCApi.md#get_voter) | **GET** /api/v1/ug/kyc/voter | Voters ID
*WalletApi* | [**create_wallet**](docs/WalletApi.md#create_wallet) | **POST** /v1/wallet/ngn/create | Create NGN Wallet
*WalletApi* | [**credit_subwallet**](docs/WalletApi.md#credit_subwallet) | **POST** /v1/wallet/ngn/credit | Credit Sub-wallet
*WalletApi* | [**get_transaction**](docs/WalletApi.md#get_transaction) | **GET** /v1/wallet/ngn/transaction | Retrieve Transaction Details
*WalletApi* | [**get_wallet**](docs/WalletApi.md#get_wallet) | **GET** /v1/wallet/ngn/retrieve | Retrieve Wallet Details
*WalletApi* | [**get_wallets**](docs/WalletApi.md#get_wallets) | **GET** /v1/wallet/ngn/accounts | Get Wallets
*WalletApi* | [**transfer_funds**](docs/WalletApi.md#transfer_funds) | **POST** /v1/wallet/ngn/transfer | Transfer Funds
*WebHooksApi* | [**delete_webhook**](docs/WebHooksApi.md#delete_webhook) | **DELETE** /api/v1/webhook/delete | Delete Webhook
*WebHooksApi* | [**get_webhooks**](docs/WebHooksApi.md#get_webhooks) | **GET** /api/v1/webhook/fetch | Fetch All Webhooks
*WebHooksApi* | [**notify_webhook**](docs/WebHooksApi.md#notify_webhook) | **POST** /api/v1/webhook/notify | Post Hook
*WebHooksApi* | [**subscribe_service**](docs/WebHooksApi.md#subscribe_service) | **POST** /api/v1/webhook/subscribe | Subscribe to service


## Documentation For Models

 - [AnalyzeDocumentResponse](docs/AnalyzeDocumentResponse.md)
 - [AnalyzeDocumentResponseEntity](docs/AnalyzeDocumentResponseEntity.md)
 - [AnalyzeDocumentResponseEntityDocumentImages](docs/AnalyzeDocumentResponseEntityDocumentImages.md)
 - [AnalyzeDocumentResponseEntityDocumentType](docs/AnalyzeDocumentResponseEntityDocumentType.md)
 - [AnalyzeDocumentResponseEntityStatus](docs/AnalyzeDocumentResponseEntityStatus.md)
 - [AnalyzeDocumentResponseEntityTextDataInner](docs/AnalyzeDocumentResponseEntityTextDataInner.md)
 - [CategorizeTransactionsResponse](docs/CategorizeTransactionsResponse.md)
 - [CategorizeTransactionsResponseEntity](docs/CategorizeTransactionsResponseEntity.md)
 - [CollectStatusFromPdfResponse](docs/CollectStatusFromPdfResponse.md)
 - [CollectTransactionsResponse](docs/CollectTransactionsResponse.md)
 - [CollectTransactionsResponseEntity](docs/CollectTransactionsResponseEntity.md)
 - [CreateWalletResponse](docs/CreateWalletResponse.md)
 - [CreateWalletResponseEntity](docs/CreateWalletResponseEntity.md)
 - [CreditSubwalletResponse](docs/CreditSubwalletResponse.md)
 - [CreditSubwalletResponseEntity](docs/CreditSubwalletResponseEntity.md)
 - [DeleteWebhookResponse](docs/DeleteWebhookResponse.md)
 - [FinancialGetBasicBvnResponse](docs/FinancialGetBasicBvnResponse.md)
 - [FinancialGetBasicBvnResponseEntity](docs/FinancialGetBasicBvnResponseEntity.md)
 - [FinancialGetFullBvnResponse](docs/FinancialGetFullBvnResponse.md)
 - [FinancialGetFullBvnResponseEntity](docs/FinancialGetFullBvnResponseEntity.md)
 - [GeneralGetNubanResponse](docs/GeneralGetNubanResponse.md)
 - [GeneralGetNubanResponseEntity](docs/GeneralGetNubanResponseEntity.md)
 - [GeneralGetWalletBalanceResponse](docs/GeneralGetWalletBalanceResponse.md)
 - [GetAccountAnalysisResponse](docs/GetAccountAnalysisResponse.md)
 - [GetAccountAnalysisResponseEntity](docs/GetAccountAnalysisResponseEntity.md)
 - [GetAccountAnalysisResponseEntityAccountBreakdown](docs/GetAccountAnalysisResponseEntityAccountBreakdown.md)
 - [GetAccountAnalysisResponseEntityExpenseBreakdown](docs/GetAccountAnalysisResponseEntityExpenseBreakdown.md)
 - [GetAccountAnalysisResponseEntityFundsManagement](docs/GetAccountAnalysisResponseEntityFundsManagement.md)
 - [GetAccountAnalysisResponseEntityInflowBreakdown](docs/GetAccountAnalysisResponseEntityInflowBreakdown.md)
 - [GetAccountAnalysisResponseEntityTransactionRoutineBreakdown](docs/GetAccountAnalysisResponseEntityTransactionRoutineBreakdown.md)
 - [GetAccountResponse](docs/GetAccountResponse.md)
 - [GetAccountSubscriptionsResponse](docs/GetAccountSubscriptionsResponse.md)
 - [GetAccountSubscriptionsResponseEntity](docs/GetAccountSubscriptionsResponseEntity.md)
 - [GetAccountTransactionsResponse](docs/GetAccountTransactionsResponse.md)
 - [GetAccountTransactionsResponseEntity](docs/GetAccountTransactionsResponseEntity.md)
 - [GetAccountTransactionsResponseEntityTransactionsInner](docs/GetAccountTransactionsResponseEntityTransactionsInner.md)
 - [GetAdvancedCacResponse](docs/GetAdvancedCacResponse.md)
 - [GetBanksResponse](docs/GetBanksResponse.md)
 - [GetBanksResponseEntityInner](docs/GetBanksResponseEntityInner.md)
 - [GetBasicBvnResponse](docs/GetBasicBvnResponse.md)
 - [GetBasicBvnResponseEntity](docs/GetBasicBvnResponseEntity.md)
 - [GetBasicCacResponse](docs/GetBasicCacResponse.md)
 - [GetBasicCacResponseEntity](docs/GetBasicCacResponseEntity.md)
 - [GetBasicPhoneNumberResponse](docs/GetBasicPhoneNumberResponse.md)
 - [GetBasicPhoneNumberResponseEntity](docs/GetBasicPhoneNumberResponseEntity.md)
 - [GetBinResponse](docs/GetBinResponse.md)
 - [GetBinResponseEntity](docs/GetBinResponseEntity.md)
 - [GetCacResponse](docs/GetCacResponse.md)
 - [GetCacResponseEntity](docs/GetCacResponseEntity.md)
 - [GetDataPlansResponse](docs/GetDataPlansResponse.md)
 - [GetDocumentAnalysisResponse](docs/GetDocumentAnalysisResponse.md)
 - [GetDocumentAnalysisResponseEntity](docs/GetDocumentAnalysisResponseEntity.md)
 - [GetDocumentAnalysisResponseEntityData](docs/GetDocumentAnalysisResponseEntityData.md)
 - [GetDriversLicenseResponse](docs/GetDriversLicenseResponse.md)
 - [GetDriversLicenseResponseEntity](docs/GetDriversLicenseResponseEntity.md)
 - [GetEarningStructureResponse](docs/GetEarningStructureResponse.md)
 - [GetEarningStructureResponseEntity](docs/GetEarningStructureResponseEntity.md)
 - [GetEmailReputationResponse](docs/GetEmailReputationResponse.md)
 - [GetEmailReputationResponseEntity](docs/GetEmailReputationResponseEntity.md)
 - [GetEmailReputationResponseEntityDetails](docs/GetEmailReputationResponseEntityDetails.md)
 - [GetFullBvnResponse](docs/GetFullBvnResponse.md)
 - [GetFullBvnResponseEntity](docs/GetFullBvnResponseEntity.md)
 - [GetGenericOcrTextResponse](docs/GetGenericOcrTextResponse.md)
 - [GetKycDriversLicenseResponse](docs/GetKycDriversLicenseResponse.md)
 - [GetKycDriversLicenseResponseEntity](docs/GetKycDriversLicenseResponseEntity.md)
 - [GetKycDriversLicenseResponseEntityPersonalDetails](docs/GetKycDriversLicenseResponseEntityPersonalDetails.md)
 - [GetKycPassportResponse](docs/GetKycPassportResponse.md)
 - [GetKycPassportResponseEntity](docs/GetKycPassportResponseEntity.md)
 - [GetNationalIdResponse](docs/GetNationalIdResponse.md)
 - [GetNationalIdResponseEntity](docs/GetNationalIdResponseEntity.md)
 - [GetNubanResponse](docs/GetNubanResponse.md)
 - [GetNubanResponseEntity](docs/GetNubanResponseEntity.md)
 - [GetOcrTextResponse](docs/GetOcrTextResponse.md)
 - [GetOcrTextResponseEntity](docs/GetOcrTextResponseEntity.md)
 - [GetPassportResponse](docs/GetPassportResponse.md)
 - [GetPassportResponseEntity](docs/GetPassportResponseEntity.md)
 - [GetPhoneNumber404Response](docs/GetPhoneNumber404Response.md)
 - [GetPhoneNumberResponse](docs/GetPhoneNumberResponse.md)
 - [GetPhoneNumberResponseEntity](docs/GetPhoneNumberResponseEntity.md)
 - [GetPremiumBvnResponse](docs/GetPremiumBvnResponse.md)
 - [GetPremiumBvnResponseEntity](docs/GetPremiumBvnResponseEntity.md)
 - [GetScreeningInfoResponse](docs/GetScreeningInfoResponse.md)
 - [GetScreeningInfoResponseEntity](docs/GetScreeningInfoResponseEntity.md)
 - [GetScreeningInfoResponseEntityResult](docs/GetScreeningInfoResponseEntityResult.md)
 - [GetSenderIdResponse](docs/GetSenderIdResponse.md)
 - [GetSenderIdResponseEntityInner](docs/GetSenderIdResponseEntityInner.md)
 - [GetSmsStatusResponse](docs/GetSmsStatusResponse.md)
 - [GetSmsStatusResponseEntity](docs/GetSmsStatusResponseEntity.md)
 - [GetSpendingPatternResponse](docs/GetSpendingPatternResponse.md)
 - [GetSpendingPatternResponseEntity](docs/GetSpendingPatternResponseEntity.md)
 - [GetSpendingPatternResponseEntityPattern](docs/GetSpendingPatternResponseEntityPattern.md)
 - [GetSpendingPatternResponseEntityPatternAirtimeData](docs/GetSpendingPatternResponseEntityPatternAirtimeData.md)
 - [GetSpendingPatternResponseEntityPatternBankTransfer](docs/GetSpendingPatternResponseEntityPatternBankTransfer.md)
 - [GetSpendingPatternResponseEntityPatternCharges](docs/GetSpendingPatternResponseEntityPatternCharges.md)
 - [GetSpendingPatternResponseEntityPatternFood](docs/GetSpendingPatternResponseEntityPatternFood.md)
 - [GetSpendingPatternResponseEntityPatternOthers](docs/GetSpendingPatternResponseEntityPatternOthers.md)
 - [GetSsnitResponse](docs/GetSsnitResponse.md)
 - [GetSsnitResponseEntity](docs/GetSsnitResponseEntity.md)
 - [GetTinResponse](docs/GetTinResponse.md)
 - [GetTinResponseEntity](docs/GetTinResponseEntity.md)
 - [GetTransactionResponse](docs/GetTransactionResponse.md)
 - [GetTransactionResponseEntity](docs/GetTransactionResponseEntity.md)
 - [GetVinResponse](docs/GetVinResponse.md)
 - [GetVinResponseEntity](docs/GetVinResponseEntity.md)
 - [GetVninResponse](docs/GetVninResponse.md)
 - [GetVninResponseEntity](docs/GetVninResponseEntity.md)
 - [GetVoterResponse](docs/GetVoterResponse.md)
 - [GetVoterResponseEntity](docs/GetVoterResponseEntity.md)
 - [GetWalletBalanceResponse](docs/GetWalletBalanceResponse.md)
 - [GetWalletBalanceResponseEntity](docs/GetWalletBalanceResponseEntity.md)
 - [GetWalletResponse](docs/GetWalletResponse.md)
 - [GetWalletResponseEntity](docs/GetWalletResponseEntity.md)
 - [GetWalletsResponse](docs/GetWalletsResponse.md)
 - [GetWalletsResponseEntity](docs/GetWalletsResponseEntity.md)
 - [GetWebhooksResponse](docs/GetWebhooksResponse.md)
 - [GetWebhooksResponseEntityInner](docs/GetWebhooksResponseEntityInner.md)
 - [NotifyWebhookResponse](docs/NotifyWebhookResponse.md)
 - [PurchaseAirtimeResponse](docs/PurchaseAirtimeResponse.md)
 - [PurchaseAirtimeResponseEntity](docs/PurchaseAirtimeResponseEntity.md)
 - [PurchaseAirtimeResponseEntityDataInner](docs/PurchaseAirtimeResponseEntityDataInner.md)
 - [PurchaseDataResponse](docs/PurchaseDataResponse.md)
 - [PurchaseDataResponseEntityInner](docs/PurchaseDataResponseEntityInner.md)
 - [RequestSenderIdResponse](docs/RequestSenderIdResponse.md)
 - [RequestSenderIdResponseEntityInner](docs/RequestSenderIdResponseEntityInner.md)
 - [ScreenAmlResponse](docs/ScreenAmlResponse.md)
 - [ScreenAmlResponseEntity](docs/ScreenAmlResponseEntity.md)
 - [SendOtpResponse](docs/SendOtpResponse.md)
 - [SendOtpResponseEntityInner](docs/SendOtpResponseEntityInner.md)
 - [SendSmsResponse](docs/SendSmsResponse.md)
 - [SendSmsResponseEntity](docs/SendSmsResponseEntity.md)
 - [SubscribeServiceResponse](docs/SubscribeServiceResponse.md)
 - [TransferFundsResponse](docs/TransferFundsResponse.md)
 - [TransferFundsResponseEntity](docs/TransferFundsResponseEntity.md)
 - [ValidateBvnResponse](docs/ValidateBvnResponse.md)
 - [ValidateBvnResponseEntity](docs/ValidateBvnResponseEntity.md)
 - [ValidateBvnResponseEntityBvn](docs/ValidateBvnResponseEntityBvn.md)
 - [ValidateBvnResponseEntityFirstName](docs/ValidateBvnResponseEntityFirstName.md)
 - [ValidateOtpResponse](docs/ValidateOtpResponse.md)
 - [ValidateOtpResponseEntity](docs/ValidateOtpResponseEntity.md)
 - [VerifyAgeResponse](docs/VerifyAgeResponse.md)
 - [VerifyAgeResponseEntity](docs/VerifyAgeResponseEntity.md)
 - [VerifyPhotoIdWithSelfieResponse](docs/VerifyPhotoIdWithSelfieResponse.md)
 - [VerifyPhotoIdWithSelfieResponseEntity](docs/VerifyPhotoIdWithSelfieResponseEntity.md)
 - [VerifyPhotoIdWithSelfieResponseEntitySelfie](docs/VerifyPhotoIdWithSelfieResponseEntitySelfie.md)
 - [VerifySelfieBvnResponse](docs/VerifySelfieBvnResponse.md)
 - [VerifySelfieBvnResponseEntity](docs/VerifySelfieBvnResponseEntity.md)
 - [VerifySelfieBvnResponseEntitySelfieVerification](docs/VerifySelfieBvnResponseEntitySelfieVerification.md)
 - [VerifySelfieNinResponse](docs/VerifySelfieNinResponse.md)
 - [VerifySelfieNinResponseEntity](docs/VerifySelfieNinResponseEntity.md)
 - [VerifySelfieNinResponseEntitySelfieVerification](docs/VerifySelfieNinResponseEntitySelfieVerification.md)


## Documentation For Authorization


## apikeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## appIdAuth

- **Type**: API key
- **API key parameter name**: AppId
- **Location**: HTTP header


## Author




## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in dojah_client.apis and dojah_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from dojah_client.api.default_api import DefaultApi`
- `from dojah_client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import dojah_client
from dojah_client.apis import *
from dojah_client.models import *
```

